"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const webpack = require("webpack");
const WebpackCompilationError_1 = require("../errors/WebpackCompilationError");
/**
 * Simple controller for `webpack`
 *
 * @export
 * @class WebpackController
 */
class WebpackController {
    /**
     * Creates an instance of WebpackController.
     *
     * @param {Configuration} config
     * @memberof WebpackController
     */
    constructor(config) {
        this.config = config;
    }
    /**
     * Execute webpack
     *
     * @returns {Compiler.Watching | Compiler}
     * @memberof WebpackController
     */
    compile() {
        return new Promise((resolve, reject) => {
            this.compiler = webpack(this.config, (err, stats) => {
                if (err)
                    return reject(err);
                if (stats.hasErrors())
                    return reject(new WebpackCompilationError_1.default(stats));
                if (stats.hasWarnings()) {
                    console.warn(stats.toJson().warnings);
                }
                resolve((this.stats = stats));
            });
        });
    }
}
exports.default = WebpackController;
//# sourceMappingURL=WebpackController.js.map